summaryrefslogtreecommitdiffstats
path: root/src/H5P.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5P.c')
-rw-r--r--src/H5P.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/H5P.c b/src/H5P.c
index 63537f0..f88ec60 100644
--- a/src/H5P.c
+++ b/src/H5P.c
@@ -1847,7 +1847,7 @@ H5Pget_driver(hid_t plist_id)
* Rewritten to use the virtual file layer.
*
* Robb Matzke, 1999-08-05
* If the driver ID is -2 then substitute the current value of
* H5FD_SEC2.
*-------------------------------------------------------------------------
*/
@@ -1874,7 +1874,7 @@ H5Pget_driver(hid_t plist_id)
"not a file access or data transfer property list");
}
- if (H5P_DEFAULT==ret_value)
+ if (H5FD_VFD_DEFAULT==ret_value)
ret_value = H5FD_SEC2;
FUNC_LEAVE(ret_value);
@@ -1847,7 +1847,7 @@ H5Pget_driver(hid_t plist_id)
*
* Robb Matzke, 1999-08-05
- * If the driver ID is -2 then substitute the current value of
+ * If the driver ID is H5FD_VFD_DEFAULT then substitute the current value of
* H5FD_SEC2.
*-------------------------------------------------------------------------